!!! warning
    This page is under construction. The content may be incomplete or incorrect. Submit an issue
    on [GitHub](https://github.com/QuEraComputing/kirin/issues/new) if you need help or want to
    contribute.

# Python Dialects

Kirin provides a set of dialects that represents fractions of Python semantics. We will describe
each dialect in this page. The general design principle of these dialects is to provide a composable
set of Python semantics that can be used to build different embedded DSLs inside Python.
